==> mapbox-android-telemetry-6.1.0-sources.jar: com/mapbox/android/telemetry/ComCertificatePins.java <==
package com.mapbox.android.telemetry;


import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

class ComCertificatePins {

  static final Map<String, List<String>> CERTIFICATE_PINS = new HashMap<String, List<String>>() {
    {
      put("events.mapbox.com", new ArrayList<String>() {
        {
          add("BhynraKizavqoC5U26qgYuxLZst6pCu9J5stfL6RSYY=");
          add("owrR9U9FWDWtrFF+myoRIu75JwU4sJwzvhCNLZoY37g=");
          add("SQVGZiOrQXi+kqxcvWWE96HhfydlLVqFr4lQTqI5qqo=");
          add("yJLOJQLNTPNSOh3Btyg9UA1icIoZZssWzG0UmVEJFfA=");
          add("Tb0uHZ/KQjWh8N9+CZFLc4zx36LONQ55l6laDi1qtT4=");
          add("RRM1dGqnDFsCJXBTHky16vi1obOlCgFFn/yOhI/y+ho=");
          add("WoiWRyIOVNa9ihaBciRSC7XHjliYS9VwUGOIud4PB18=");
          add("yGp2XoimPmIK24X3bNV1IaK+HqvbGEgqar5nauDdC5E=");

          add("6+ErFga5JfYfvwx2JbEJJNmUXJFnXIKllrbPKmvWqNc=");
          add("vLkrnr8JTAVaYPwY/jBkKCe+YQWleaHPU3Tlqom+gCg=");
          add("UofZo86l1bDjTiHyKXurqgfkYaYjtjyTrOYYR68XLG8=");
          add("wSE/ahOwDVj7tMLMOjoAr1gIoBoWrUhQOBliQ82/bGk=");
          add("RKHNDCiwHVTR5vKksBOcpfaojpsfCMFQ9MAE01ac8Tk=");
          add("enUlaLivnHjrJBFVcvr8gwVTVcjXWOv8n96jU5towo8=");
          add("Cul962ner+uZmwBQybZi0CHlFiZ3uFnZJe/lKqnqL6k=");
          add("WswAtgVhFf6bIpavbiBL2GOP+e/zWqnECQrK17qKOLU=");
          add("O+4Y2hugHTXgiaf6s2Zt4Vc7M3l3lLLu+6ugYGLI1x0=");
          add("tfeXXd8OZXRbuZgeOanQAsgQlgdh4GBIIyCDvULtwLA=");
          add("A+vWP93KGIMHeADZtj9S/mSIQtvzGz5G671aRKf3NlY=");
          add("malXG7/2Qay6uSfQxLGm2Lob8MVjSPkzNrtdnwpHhuA=");
          add("zfBsiWe9eHeGevBcYtrGiPQ0zCr2IvB08S7ESSWqVN8=");
          add("o8bx+G1dysezoWAvOXBsl4/E6LcABFSqy6J8si5Cryk=");
          add("YrsgZS2RzrUtunIndi031Ye/HyMn7WQQweav4xgR6qk=");
          add("HQqyJQU7b+X/v1297LXK4TxKMwdC72Qzqy7Jx5W3LgA=");
          add("00lmpHvG3dPLQ/hsewpHNLsK9vruPV+0hcQAl7FmRxI=");
          add("lrmOBGfUptzfKOgSLUCKRvhfYNLH94x2ZKaX5ijBbTs=");
          add("nf4V9/G5BE3bNy7TDkvqc7MaIkfcA625hjtQM7FJkcM=");
          add("/0K/iJYfENe5o5arEhWfT7sailUd/QBY3ws0wD9dggU=");
          add("SDnReAbazEH28n7pV5M/8A0M8ggJrO8/teE7oCJ7OGU=");
          add("gruIKpo+vo5XKJ8t6yoPeNrpjWSsdnyaxkSLe/vSz2U=");
          add("a4CTRze+fw6iUhnKA7Ph2Qt41eco42RBFcHITnYcNoY=");
          add("8wc+3VCcufdq1JzdsxtaleFLA/u/peBtjfdPOeFKsIo=");
          add("a5foMaNKMbLYMnB079u3G2oxhSRSHilwljENMsBiQwE=");
          add("r1t+lUCzuncTnfM/QtclWIA7zhN8AYYUWlIimDhI0HM=");
          add("dFS5RaEoQf7naXnfYnP1AuQMxyJwygHAXRG4bOZD6OM=");
          add("zSAUiJZbnZdUu2bKUNf21r7RXJPzHGuMFxwPx7aLhfg=");
          add("UmlVTDcbkUR075i+thE9Q1fOxPIGn8PmQ51R+XL4fK8=");
          add("Zx+aoQE1cmiSN1TwvCo1Qpvuwjbq35eH4DsmkXKacIo=");
          add("TAOftRoKGrOsFjgCtUzHswja6MykOf9UZaoljB6TYso=");
          add("tW+psPLgOjPSsSMZPxc/PDGw0vBIpIZz32av4NEzVjc=");
          add("35zTxuHmPcNqJ5OSW02V+9ghV3TJYmBI3arMTuC1z9w=");
          add("ciiuiChtsyaTUEkDZ/N1KJaAgr4bIAIM13R0B9NVt6M=");
          add("cwUwdyqZ6YOMWX5zcJcYarQ5okvMLxj/Rd4dUpkRFHM=");
          add("tShTLeS4OltlKlE3MQUvXlJsGrCFgFo/nXvl5t0qba8=");
          add("qy6BTLAetvqNOFfT/M3pZSRo9FRaF8KudDGgHy8Fxis=");
          add("AOOutVCG4tDUsn13XyTAsx3cTZtIGajdCxSJoGZ+jp4=");
          add("0LqMhNP7UHpAVl6+ON7AzsqeMWZb1ElB5AL0kPS6ktI=");
          add("Zqng4S5spV0NeKT8MrE8CJFMBTP188PG9iEi7/9HDyo=");
          add("i/4rsupujT8Ww/2yIGJ3wb6R7GDw2FHPyOM5sWh87DQ=");
          add("cvlddgcP0XDOIKnCr+h+2zy2Tt8pnCPdw1l+PiEyS5o=");
          add("UhpcxVytZbC4dx2Dnjjg6k02Ylf5jLo3C3AxchaKhh0=");
          add("ZJfLxFuRg/1giSVrnj6aZmU5T//PP2eU7NLXXeqdH7s=");
          add("ZnL4xB/aLV5W0YSZVefBRZSRTeoLzjJkk7CBvz75/m8=");
          add("d4GNs3j9rUym4ogDTWX7AXTaI3K3gt46S2tvL6Hh/bQ=");
          add("R9Wa2ON8VRWRF5OyDDaSDMhf7ysK1ykV1XSq20RMDFM=");
          add("QMMBDJh3g1QgkGV6m+T4i2weBGj/W2+fVG73slK3mJE=");
          add("ENU8M1yItdL5EP0G+I4hz4iuGlAUIHWCe4ipwXB/c/A=");
          add("PA1lecwXNRXY/Vpy0VN+jQEYChN4hCAF36oB0Ygx3wQ=");
        }
      });
      put("FVQ3CP/SEI8eLPxHJnjyew2P5DTC1OBKK4Y6XkmC0WI=", new ArrayList<String>() {
        {
          add("qjl/5X6sDeDCP4DEcR4VFPw0qa/El98EU/ZHwY0jTx0=");
          add("Xw7GYmoUa7YVrYJj7t7RnqYcO58dRFLYEL7UEOuIlX8=");
        }
      });
    }
  };
}

==> mapbox-android-telemetry-6.2.1-sources.jar: com/mapbox/android/telemetry/ComCertificatePins.java <==
package com.mapbox.android.telemetry;


import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

class ComCertificatePins {

  static final Map<String, List<String>> CERTIFICATE_PINS = new HashMap<String, List<String>>() {
    {
      put("**.mapbox.com", new ArrayList<String>() {
        {
          add("BhynraKizavqoC5U26qgYuxLZst6pCu9J5stfL6RSYY=");
          add("owrR9U9FWDWtrFF+myoRIu75JwU4sJwzvhCNLZoY37g=");
          add("SQVGZiOrQXi+kqxcvWWE96HhfydlLVqFr4lQTqI5qqo=");
          add("yJLOJQLNTPNSOh3Btyg9UA1icIoZZssWzG0UmVEJFfA=");
          add("Tb0uHZ/KQjWh8N9+CZFLc4zx36LONQ55l6laDi1qtT4=");
          add("RRM1dGqnDFsCJXBTHky16vi1obOlCgFFn/yOhI/y+ho=");
          add("WoiWRyIOVNa9ihaBciRSC7XHjliYS9VwUGOIud4PB18=");
          add("yGp2XoimPmIK24X3bNV1IaK+HqvbGEgqar5nauDdC5E=");

          add("6+ErFga5JfYfvwx2JbEJJNmUXJFnXIKllrbPKmvWqNc=");
          add("vLkrnr8JTAVaYPwY/jBkKCe+YQWleaHPU3Tlqom+gCg=");
          add("UofZo86l1bDjTiHyKXurqgfkYaYjtjyTrOYYR68XLG8=");
          add("wSE/ahOwDVj7tMLMOjoAr1gIoBoWrUhQOBliQ82/bGk=");
          add("RKHNDCiwHVTR5vKksBOcpfaojpsfCMFQ9MAE01ac8Tk=");
          add("enUlaLivnHjrJBFVcvr8gwVTVcjXWOv8n96jU5towo8=");
          add("Cul962ner+uZmwBQybZi0CHlFiZ3uFnZJe/lKqnqL6k=");
          add("WswAtgVhFf6bIpavbiBL2GOP+e/zWqnECQrK17qKOLU=");
          add("O+4Y2hugHTXgiaf6s2Zt4Vc7M3l3lLLu+6ugYGLI1x0=");
          add("tfeXXd8OZXRbuZgeOanQAsgQlgdh4GBIIyCDvULtwLA=");
          add("A+vWP93KGIMHeADZtj9S/mSIQtvzGz5G671aRKf3NlY=");
          add("malXG7/2Qay6uSfQxLGm2Lob8MVjSPkzNrtdnwpHhuA=");
          add("zfBsiWe9eHeGevBcYtrGiPQ0zCr2IvB08S7ESSWqVN8=");
          add("o8bx+G1dysezoWAvOXBsl4/E6LcABFSqy6J8si5Cryk=");
          add("YrsgZS2RzrUtunIndi031Ye/HyMn7WQQweav4xgR6qk=");
          add("HQqyJQU7b+X/v1297LXK4TxKMwdC72Qzqy7Jx5W3LgA=");
          add("00lmpHvG3dPLQ/hsewpHNLsK9vruPV+0hcQAl7FmRxI=");
          add("lrmOBGfUptzfKOgSLUCKRvhfYNLH94x2ZKaX5ijBbTs=");
          add("nf4V9/G5BE3bNy7TDkvqc7MaIkfcA625hjtQM7FJkcM=");
          add("/0K/iJYfENe5o5arEhWfT7sailUd/QBY3ws0wD9dggU=");
          add("SDnReAbazEH28n7pV5M/8A0M8ggJrO8/teE7oCJ7OGU=");
          add("gruIKpo+vo5XKJ8t6yoPeNrpjWSsdnyaxkSLe/vSz2U=");
          add("a4CTRze+fw6iUhnKA7Ph2Qt41eco42RBFcHITnYcNoY=");
          add("8wc+3VCcufdq1JzdsxtaleFLA/u/peBtjfdPOeFKsIo=");
          add("a5foMaNKMbLYMnB079u3G2oxhSRSHilwljENMsBiQwE=");
          add("r1t+lUCzuncTnfM/QtclWIA7zhN8AYYUWlIimDhI0HM=");
          add("dFS5RaEoQf7naXnfYnP1AuQMxyJwygHAXRG4bOZD6OM=");
          add("zSAUiJZbnZdUu2bKUNf21r7RXJPzHGuMFxwPx7aLhfg=");
          add("UmlVTDcbkUR075i+thE9Q1fOxPIGn8PmQ51R+XL4fK8=");
          add("Zx+aoQE1cmiSN1TwvCo1Qpvuwjbq35eH4DsmkXKacIo=");
          add("TAOftRoKGrOsFjgCtUzHswja6MykOf9UZaoljB6TYso=");
          add("tW+psPLgOjPSsSMZPxc/PDGw0vBIpIZz32av4NEzVjc=");
          add("35zTxuHmPcNqJ5OSW02V+9ghV3TJYmBI3arMTuC1z9w=");
          add("ciiuiChtsyaTUEkDZ/N1KJaAgr4bIAIM13R0B9NVt6M=");
          add("cwUwdyqZ6YOMWX5zcJcYarQ5okvMLxj/Rd4dUpkRFHM=");
          add("tShTLeS4OltlKlE3MQUvXlJsGrCFgFo/nXvl5t0qba8=");
          add("qy6BTLAetvqNOFfT/M3pZSRo9FRaF8KudDGgHy8Fxis=");
          add("AOOutVCG4tDUsn13XyTAsx3cTZtIGajdCxSJoGZ+jp4=");
          add("0LqMhNP7UHpAVl6+ON7AzsqeMWZb1ElB5AL0kPS6ktI=");
          add("Zqng4S5spV0NeKT8MrE8CJFMBTP188PG9iEi7/9HDyo=");
          add("i/4rsupujT8Ww/2yIGJ3wb6R7GDw2FHPyOM5sWh87DQ=");
          add("cvlddgcP0XDOIKnCr+h+2zy2Tt8pnCPdw1l+PiEyS5o=");
          add("UhpcxVytZbC4dx2Dnjjg6k02Ylf5jLo3C3AxchaKhh0=");
          add("ZJfLxFuRg/1giSVrnj6aZmU5T//PP2eU7NLXXeqdH7s=");
          add("ZnL4xB/aLV5W0YSZVefBRZSRTeoLzjJkk7CBvz75/m8=");
          add("d4GNs3j9rUym4ogDTWX7AXTaI3K3gt46S2tvL6Hh/bQ=");
          add("R9Wa2ON8VRWRF5OyDDaSDMhf7ysK1ykV1XSq20RMDFM=");
          add("QMMBDJh3g1QgkGV6m+T4i2weBGj/W2+fVG73slK3mJE=");
          add("ENU8M1yItdL5EP0G+I4hz4iuGlAUIHWCe4ipwXB/c/A=");
          add("PA1lecwXNRXY/Vpy0VN+jQEYChN4hCAF36oB0Ygx3wQ=");
          add("qjl/5X6sDeDCP4DEcR4VFPw0qa/El98EU/ZHwY0jTx0=");
          add("Xw7GYmoUa7YVrYJj7t7RnqYcO58dRFLYEL7UEOuIlX8=");
        }
      });
    }
  };
}
